@@ -6,6 +6,8 @@ fp.sim.matrix <- function(fplist, fplist2=NULL, method='tanimoto') {
 
   if (method == 'dice') {
     return(.dice.sim.mat(fplist))
+  } else if (method == 'tanimoto') {
+    return(.tanimoto.sim.mat(fplist))
   }
   
   sim <- matrix(0,nrow=length(fplist), ncol=length(fplist))
@@ -54,3 +56,22 @@ fp.factor.matrix <- function( fplist ) {
   diag(s) <- 1.0  
   return(s)
 }
+
+.tanimoto.sim.mat <- function(fplist){
+  m <- fp.to.matrix(fplist)
+  mat<-m%*%t(m)
+  len<-length(m[,1])
+  s<-mat.or.vec(len,len)
+  
+  ret <-  .C("m_tanimoto", as.double(mat), as.integer(len), as.double(s),
+             PACKAGE="fingerprint")
+  ret <- matrix(ret[[3]], nrow=len, ncol=len, byrow=TRUE)
+  return(ret)
+  
+  ## for (i in 1:len){
+  ##   for (j in 1:len){
+  ##     s[i,j]<- mat[i,j]/(mat[i,i]+mat[j,j]-mat[i,j]) # Formula for Tanimoto Calculation
+  ##   }
+  ## }
+  ## return(s)
+}
